# dockerjudge
[![Build Status](https://www.travis-ci.org/wangxinhe2006/dockerjudge.svg)](https://www.travis-ci.org/wangxinhe2006/dockerjudge)
[![License](https://img.shields.io/github/license/wangxinhe2006/dockerjudge.svg)](https://img.shields.io/github/license/wangxinhe2006/dockerjudge.svg)

A Docker Based Online Judge Engine

# [License](LICENSE)
Licensed under [the GNU Affero General Public License v3.0](https://www.gnu.org/licenses/agpl-3.0.html)

[![agplv3-155x51.png](https://www.gnu.org/graphics/agplv3-155x51.png)](https://www.gnu.org/graphics/agplv3-155x51.png)
